@@ -8,11 +8,12 @@ logger = logging.getLogger(__name__)
 
 
 class TidalPlaybackProvider(backend.PlaybackProvider):
-
     def translate_uri(self, uri):
         logger.info("TIDAL uri: %s", uri)
-        parts = uri.split(':')
+        parts = uri.split(":")
         track_id = int(parts[4])
-        newurl = self.backend._session.get_media_url(track_id)
+        session = self.backend._session
+
+        newurl = session.track(track_id).get_url()
         logger.info("transformed into %s", newurl)
         return newurl
